package com.abcsz.litigationcase.utils;

import com.abcsz.vhost.exception.DFException;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.net.HttpURLConnection;
import java.net.URL;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Slf4j
@Component
public class JumpUtil {

	@Value("${abcsz.jumpurl.two.url}")
	private String jumpTwoUrl;
	@Value("${abcsz.jumpurl.two.sendsite}")
	private String jumpTowSendSite;
	
	public String httpPost(String url, String inputStr, List<AbcszHeader> headers) throws Exception {
		
		log.info("调用互联网出口" + url);
		SimpleDateFormat df = new SimpleDateFormat("yyyyMMddHHmmss");
		JSONObject clientData = new JSONObject();
		
		clientData.put("webserviceMethod", url);
		clientData.put("requestMsg", inputStr);
		clientData.put("HeadMap", headers);
		
		String context = clientData.toString();
		Date curDate = new Date();
		JSONObject routeObject = new JSONObject();
		routeObject.put("sendsite", jumpTowSendSite);
		routeObject.put("id", df.format(curDate));
		routeObject.put("reqtime", df.format(curDate));
		routeObject.put("method", "UploadData");
		routeObject.put("rq", context);
		
		String finalInput = routeObject.toString();
		
		log.info("出口全报文");
		log.info(finalInput);
		
		String outputString = sendPost(jumpTwoUrl, finalInput);
		log.info("返回全报文");
		log.info(outputString);
		JSONObject outputObj =JSONObject.parseObject(outputString);
		
		if(!"0000".equals(outputObj.getString("RetCode"))) {
			log.error("调用出口失败");
			log.error(outputString);
			throw new DFException("调用错误");
		}
		
		String clientOutStr = outputObj.getString("rs");
		JSONObject clientOut = JSONObject.parseObject(clientOutStr);
		if(!"0000".equals(clientOut.getString("RetCode"))){
			log.error("调用出口失败");
			log.error(clientOutStr);
			throw new DFException("调用错误");
		}
		
		return clientOut.getString("responseMsg");
	}
	
public String httpGet(String url, List<AbcszHeader> headers) throws Exception {
		
		log.info("调用互联网出口" + url);
		SimpleDateFormat df = new SimpleDateFormat("yyyyMMddHHmmss");
		JSONObject clientData = new JSONObject();
		
		clientData.put("webserviceMethod", url);
		clientData.put("requestMsg", "");
		clientData.put("HeadMap", headers);
		
		String context = clientData.toString();
		Date curDate = new Date();
		JSONObject routeObject = new JSONObject();
		routeObject.put("sendsite", jumpTowSendSite);
		routeObject.put("id", df.format(curDate));
		routeObject.put("reqtime", df.format(curDate));
		routeObject.put("method", "DownloadData");
		routeObject.put("rq", context);
		
		String finalInput = routeObject.toString();
		
		log.info("出口全报文");
		log.info(finalInput);
		
		String outputString = sendPost(jumpTwoUrl, finalInput);
		
		if(outputString==null || "".equals(outputString)) {
			log.error("调用出口失败");
			throw new DFException("调用出口失败");
		}
		
		log.info("返回全报文");
		log.info(outputString);
		JSONObject outputObj =JSONObject.parseObject(outputString);
		
		if(!"0000".equals(outputObj.getString("RetCode"))) {
			log.error("调用出口失败");
			log.error(outputString);
			throw new DFException("调用错误");
		}
		
		String clientOutStr = outputObj.getString("rs");
		JSONObject clientOut = JSONObject.parseObject(clientOutStr);
		if(!"0000".equals(clientOut.getString("RetCode"))){
			log.error("调用出口失败");
			log.error(clientOutStr);
			throw new DFException("调用错误");
		}
		
		return clientOut.getString("responseMsg");
	}
	
	 public String sendPost(String URL, String jsonStr){  
		    log.info("URL"+URL);

		    OutputStreamWriter out = null;
	        BufferedReader in = null;
	        StringBuilder result = new StringBuilder();
	        HttpURLConnection conn = null;
	        try{
	            URL url = new URL(URL);
	            conn = (HttpURLConnection) url.openConnection();
	            conn.setRequestMethod("POST");
	            //发送POST请求必须设置为true
	            conn.setDoOutput(true);
	            conn.setDoInput(true);
	            //设置连接超时时间和读取超时时间
	            conn.setConnectTimeout(30000);
	            conn.setReadTimeout(30000);
	            conn.setRequestProperty("Content-Type", "application/json");
	            conn.setRequestProperty("Accept", "application/json");
	            //获取输出流
	            out = new OutputStreamWriter(conn.getOutputStream(), "UTF-8");

	            out.write(jsonStr);
	            out.flush();
	            out.close();
	            //取得输入流，并使用Reader读取
	            if (200 == conn.getResponseCode()){
	                in = new BufferedReader(new InputStreamReader(conn.getInputStream(), "UTF-8"));
	                String line;
	                while ((line = in.readLine()) != null){
	                    result.append(line);
	                }
	            }else{
	            	throw new DFException("HTTP返回不是200:" + conn.getResponseCode());
	            }
	        }catch (Exception e){
				log.info("sendPost:" + e.getMessage() + "****" +e.getStackTrace());

				e.printStackTrace();
	        }finally {
	            try{
	                if(out != null){
	                    out.close();
	                }
	                if(in != null){
	                    in.close();
	                }
	            }catch (IOException ioe){
	                ioe.printStackTrace();
	            }
	        }
		 	log.info("调用接口返回:"+result.toString());
	        return result.toString();
	    }
	 public String sendPostWithHeader(String URL, String jsonStr, Map<String, String> headers){
	        OutputStreamWriter out = null;
	        BufferedReader in = null;
	        StringBuilder result = new StringBuilder();
	        HttpURLConnection conn = null;
	        try{
	            URL url = new URL(URL);
	            conn = (HttpURLConnection) url.openConnection();
	            conn.setRequestMethod("POST");
	            //发送POST请求必须设置为true
	            conn.setDoOutput(true);
	            conn.setDoInput(true);
	            //设置连接超时时间和读取超时时间
	            conn.setConnectTimeout(30000);
	            conn.setReadTimeout(10000);
	            
	            for(Map.Entry<String, String> item : headers.entrySet()){
	            	conn.setRequestProperty(item.getKey(), item.getValue());
	            }
	            //conn.setRequestProperty("Content-Type", "application/json");
	            //conn.setRequestProperty("Accept", "application/json");
	            //获取输出流
	            out = new OutputStreamWriter(conn.getOutputStream(),"UTF-8");
	            
	            out.write(jsonStr);
	            out.flush();
	            out.close();
	            //取得输入流，并使用Reader读取
	            if (200 == conn.getResponseCode()){
	                in = new BufferedReader(new InputStreamReader(conn.getInputStream(), "UTF-8"));
	                String line;
	                while ((line = in.readLine()) != null){
	                    result.append(line);
	                }
	            }else{
	            	throw new DFException("HTTP返回不是200:" + conn.getResponseCode());
	            }
	        }catch (Exception e){
	            e.printStackTrace();
	        }finally {
	            try{
	                if(out != null){
	                    out.close();
	                }
	                if(in != null){
	                    in.close();
	                }
	            }catch (IOException ioe){
	                ioe.printStackTrace();
	            }
	        }
	        return result.toString();
	    }
	 public String sendGetWithHeader(String URL, Map<String, String> headers){
	        //OutputStreamWriter out = null;
	        BufferedReader in = null;
	        StringBuilder result = new StringBuilder();
	        HttpURLConnection conn = null;
	        try{
	            URL url = new URL(URL);
	            conn = (HttpURLConnection) url.openConnection();
	            conn.setRequestMethod("GET");
	            //发送POST请求必须设置为true
	            //conn.setDoOutput(true);
	            //conn.setDoInput(true);
	            //设置连接超时时间和读取超时时间
	            conn.setConnectTimeout(30000);
	            conn.setReadTimeout(10000);
	            for(Map.Entry<String, String> item : headers.entrySet()){
	            	conn.setRequestProperty(item.getKey(), item.getValue());
	            }
	           // conn.setRequestProperty("Content-Type", "application/json");
	           // conn.setRequestProperty("Accept", "application/json");
	            //获取输出流
	         //   out = new OutputStreamWriter(conn.getOutputStream());

	         //   out.write(jsonStr);
	      //      out.flush();
	       //     out.close();
	            //取得输入流，并使用Reader读取
	            if (200 == conn.getResponseCode()){
	                in = new BufferedReader(new InputStreamReader(conn.getInputStream(), "UTF-8"));
	                String line;
	                while ((line = in.readLine()) != null){
	                    result.append(line);
	                }
	            }else{
	            	throw new DFException("HTTP返回不是200:" + conn.getResponseCode());
	            }
	        }catch (Exception e){
	            e.printStackTrace();
	        }finally {
	            try{
	                if(in != null){
	                    in.close();
	                }
	            }catch (IOException ioe){
	                ioe.printStackTrace();
	            }
	        }
	        return result.toString();
	    }
}
